vmassol 2003/08/09 07:52:17
Modified:
integration/ant/src/java/org/apache/cactus/integration/ant/container/jboss
Tag: CACTUS_15_BRANCH JBoss3xContainer.java
integration/ant/src/java/org/apache/cactus/integration/ant/container
Tag: CACTUS_15_BRANCH GenericContainer.java
integration/ant/src/java/org/apache/cactus/integration/ant/container/weblogic
Tag: CACTUS_15_BRANCH WebLogic7xContainer.java
integration/ant/src/java/org/apache/cactus/integration/ant/deployment
Tag: CACTUS_15_BRANCH WebXmlVersion.java
ApplicationXmlTag.java WebXmlTag.java
ApplicationXmlVersion.java
integration/ant/src/java/org/apache/cactus/integration/ant
Tag: CACTUS_15_BRANCH CactifyWarTask.java
Log:
Merged from HEAD
Revision Changes Path
No revision
No revision
1.6.2.1 +20 -1
jakarta-cactus/integration/ant/src/java/org/apache/cactus/integration/ant/container/jboss/JBoss3xContainer.java
Index: JBoss3xContainer.java
===================================================================
RCS file:
/home/cvs/jakarta-cactus/integration/ant/src/java/org/apache/cactus/integration/ant/container/jboss/JBoss3xContainer.java,v
retrieving revision 1.6
retrieving revision 1.6.2.1
diff -u -r1.6 -r1.6.2.1
--- JBoss3xContainer.java 19 Jun 2003 19:56:56 -0000 1.6
+++ JBoss3xContainer.java 9 Aug 2003 14:52:16 -0000 1.6.2.1
@@ -126,6 +126,25 @@
this.config = theConfig;
}
+ /**
+ * Sets the port that will be used to poll the server to verify if
+ * it is started. This is needed for the use case where the user
+ * has defined his own JBoss configuration by using the
+ * [EMAIL PROTECTED] #setConfig(String)} call and has defined a port other
+ * than the default one.
+ *
+ * Note: This value is not yet used to set the port
+ * to which the container will listen to. The reason is that this is
+ * hard to implement with JBoss and nobody had the courage to implement
+ * it yet...
+ *
+ * @param thePort The port to set
+ */
+ public final void setPort(int thePort)
+ {
+ this.port = thePort;
+ }
+
// Container Implementation ------------------------------------------------
/**
No revision
No revision
1.6.2.1 +9 -9
jakarta-cactus/integration/ant/src/java/org/apache/cactus/integration/ant/container/GenericContainer.java
Index: GenericContainer.java
===================================================================
RCS file:
/home/cvs/jakarta-cactus/integration/ant/src/java/org/apache/cactus/integration/ant/container/GenericContainer.java,v
retrieving revision 1.6
retrieving revision 1.6.2.1
diff -u -r1.6 -r1.6.2.1
--- GenericContainer.java 11 Jun 2003 16:17:26 -0000 1.6
+++ GenericContainer.java 9 Aug 2003 14:52:16 -0000 1.6.2.1
@@ -190,7 +190,7 @@
* @return The new hook element
* @throws BuildException If a startup hook has already been added
*/
- public final Hook createStartUp() throws BuildException
+ public Hook createStartUp() throws BuildException
{
if (isStartUpSet())
{
@@ -207,7 +207,7 @@
* @return The new hook element
* @throws BuildException If a shutdown hook has already been added
*/
- public final Hook createShutDown() throws BuildException
+ public Hook createShutDown() throws BuildException
{
if (isShutDownSet())
{
@@ -245,7 +245,7 @@
*
* @param theName The container name
*/
- public final void setName(String theName)
+ public void setName(String theName)
{
this.name = theName;
}
@@ -255,7 +255,7 @@
*
* @param thePort The port to set
*/
- public final void setPort(int thePort)
+ public void setPort(int thePort)
{
this.port = thePort;
}
@@ -297,7 +297,7 @@
/**
* @see org.apache.cactus.integration.ant.container.Container#getName
*/
- public final String getName()
+ public String getName()
{
return this.name;
}
@@ -307,7 +307,7 @@
*
* @return The port
*/
- public final int getPort()
+ public int getPort()
{
return this.port;
}
@@ -317,7 +317,7 @@
*
* @throws BuildException If thrown by the startup hook
*/
- public final void startUp() throws BuildException
+ public void startUp() throws BuildException
{
if (this.startUpHook != null)
{
@@ -330,7 +330,7 @@
*
* @throws BuildException If thrown by the shutdown hook
*/
- public final void shutDown() throws BuildException
+ public void shutDown() throws BuildException
{
if (this.shutDownHook != null)
{
No revision
No revision
1.5.2.1 +26 -52
jakarta-cactus/integration/ant/src/java/org/apache/cactus/integration/ant/container/weblogic/WebLogic7xContainer.java
Index: WebXmlVersion.java
===================================================================
RCS file:
/home/cvs/jakarta-cactus/integration/ant/src/java/org/apache/cactus/integration/ant/deployment/WebXmlVersion.java,v
retrieving revision 1.3
retrieving revision 1.3.2.1
diff -u -r1.3 -r1.3.2.1
--- WebXmlVersion.java 26 May 2003 09:52:38 -0000 1.3
+++ WebXmlVersion.java 9 Aug 2003 14:52:16 -0000 1.3.2.1
@@ -141,7 +141,7 @@
/**
* @see java.lang.Object#toString
*/
- public final boolean equals(Object theOther)
+ public boolean equals(Object theOther)
{
return super.equals(theOther);
}
@@ -149,7 +149,7 @@
/**
* @see java.lang.Object#hashCode
*/
- public final int hashCode()
+ public int hashCode()
{
return super.hashCode();
}
@@ -159,7 +159,7 @@
*
* @return The tag name
*/
- public final String getVersion()
+ public String getVersion()
{
return this.version;
}
@@ -189,7 +189,7 @@
/**
* @see java.lang.Object#toString
*/
- public final String toString()
+ public String toString()
{
return getVersion();
}
1.2.2.1 +5 -5
jakarta-cactus/integration/ant/src/java/org/apache/cactus/integration/ant/deployment/ApplicationXmlTag.java
Index: ApplicationXmlTag.java
===================================================================
RCS file:
/home/cvs/jakarta-cactus/integration/ant/src/java/org/apache/cactus/integration/ant/deployment/ApplicationXmlTag.java,v
retrieving revision 1.2
retrieving revision 1.2.2.1
diff -u -r1.2 -r1.2.2.1
--- ApplicationXmlTag.java 26 May 2003 09:52:38 -0000 1.2
+++ ApplicationXmlTag.java 9 Aug 2003 14:52:16 -0000 1.2.2.1
@@ -136,7 +136,7 @@
/**
* @see java.lang.Object#toString
*/
- public final boolean equals(Object theOther)
+ public boolean equals(Object theOther)
{
return super.equals(theOther);
}
@@ -144,7 +144,7 @@
/**
* @see java.lang.Object#hashCode
*/
- public final int hashCode()
+ public int hashCode()
{
return super.hashCode();
}
@@ -154,7 +154,7 @@
*
* @return The tag name
*/
- public final String getTagName()
+ public String getTagName()
{
return this.tagName;
}
@@ -162,7 +162,7 @@
/**
* @see java.lang.Object#toString
*/
- public final String toString()
+ public String toString()
{
return getTagName();
}
1.7.2.1 +6 -6
jakarta-cactus/integration/ant/src/java/org/apache/cactus/integration/ant/deployment/WebXmlTag.java
Index: WebXmlTag.java
===================================================================
RCS file:
/home/cvs/jakarta-cactus/integration/ant/src/java/org/apache/cactus/integration/ant/deployment/WebXmlTag.java,v
retrieving revision 1.7
retrieving revision 1.7.2.1
diff -u -r1.7 -r1.7.2.1
--- WebXmlTag.java 1 Jul 2003 19:24:35 -0000 1.7
+++ WebXmlTag.java 9 Aug 2003 14:52:16 -0000 1.7.2.1
@@ -346,7 +346,7 @@
/**
* @see java.lang.Object#toString
*/
- public final boolean equals(Object theOther)
+ public boolean equals(Object theOther)
{
return super.equals(theOther);
}
@@ -354,7 +354,7 @@
/**
* @see java.lang.Object#hashCode
*/
- public final int hashCode()
+ public int hashCode()
{
return super.hashCode();
}
@@ -364,7 +364,7 @@
*
* @return The tag name
*/
- public final String getTagName()
+ public String getTagName()
{
return this.tagName;
}
@@ -374,7 +374,7 @@
*
* @return Whether multiple occurrences are allowed
*/
- public final boolean isMultipleAllowed()
+ public boolean isMultipleAllowed()
{
return this.multipleAllowed;
}
@@ -382,7 +382,7 @@
/**
* @see java.lang.Object#toString
*/
- public final String toString()
+ public String toString()
{
return getTagName();
}
1.3.2.1 +5 -5
jakarta-cactus/integration/ant/src/java/org/apache/cactus/integration/ant/deployment/ApplicationXmlVersion.java
Index: ApplicationXmlVersion.java
===================================================================
RCS file:
/home/cvs/jakarta-cactus/integration/ant/src/java/org/apache/cactus/integration/ant/deployment/ApplicationXmlVersion.java,v
retrieving revision 1.3
retrieving revision 1.3.2.1
diff -u -r1.3 -r1.3.2.1
--- ApplicationXmlVersion.java 26 May 2003 09:52:38 -0000 1.3
+++ ApplicationXmlVersion.java 9 Aug 2003 14:52:16 -0000 1.3.2.1
@@ -144,7 +144,7 @@
/**
* @see java.lang.Object#toString
*/
- public final boolean equals(Object theOther)
+ public boolean equals(Object theOther)
{
return super.equals(theOther);
}
@@ -152,7 +152,7 @@
/**
* @see java.lang.Object#hashCode
*/
- public final int hashCode()
+ public int hashCode()
{
return super.hashCode();
}
@@ -162,7 +162,7 @@
*
* @return The tag name
*/
- public final String getVersion()
+ public String getVersion()
{
return this.version;
}
@@ -192,7 +192,7 @@
/**
* @see java.lang.Object#toString
*/
- public final String toString()
+ public String toString()
{
return getVersion();
}
No revision
No revision
1.24.2.1 +2 -2
jakarta-cactus/integration/ant/src/java/org/apache/cactus/integration/ant/CactifyWarTask.java
Index: CactifyWarTask.java
===================================================================
RCS file:
/home/cvs/jakarta-cactus/integration/ant/src/java/org/apache/cactus/integration/ant/CactifyWarTask.java,v
retrieving revision 1.24
retrieving revision 1.24.2.1
diff -u -r1.24 -r1.24.2.1
--- CactifyWarTask.java 1 Jul 2003 20:05:24 -0000 1.24
+++ CactifyWarTask.java 9 Aug 2003 14:52:17 -0000 1.24.2.1
@@ -220,7 +220,7 @@
{
if (!theWebXml.hasLoginConfig())
{
- theWebXml.setLoginConfig("BASIC", "Cactus Test Realm");
+ theWebXml.setLoginConfig("BASIC", "myrealm");
}
if (!theWebXml.hasSecurityConstraint(this.mapping))
{
---------------------------------------------------------------------
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]
Index: WebLogic7xContainer.java
===================================================================
RCS file:
/home/cvs/jakarta-cactus/integration/ant/src/java/org/apache/cactus/integration/ant/container/weblogic/WebLogic7xContainer.java,v
retrieving revision 1.5
retrieving revision 1.5.2.1
diff -u -r1.5 -r1.5.2.1
--- WebLogic7xContainer.java 15 Jun 2003 19:01:04 -0000 1.5
+++ WebLogic7xContainer.java 9 Aug 2003 14:52:16 -0000 1.5.2.1
@@ -64,7 +64,6 @@
import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.taskdefs.Jar;
import org.apache.tools.ant.taskdefs.Java;
-import org.apache.tools.ant.types.FileSet;
import org.apache.tools.ant.types.FilterChain;
import org.apache.tools.ant.types.Path;
import org.apache.tools.ant.types.ZipFileSet;
@@ -75,6 +74,7 @@
* FIXME: this doesn't work for me on JDK 1.3.1 and WL 7.0 SP2
*
* @author <a href="mailto:[EMAIL PROTECTED]">Christopher Lenz</a>
+ * @author <a href="mailto:[EMAIL PROTECTED]">Vincent Massol</a>
*
* @version $Id$
*/
@@ -89,7 +89,8 @@
private File beaHome;
/**
* The WebLogic 7.x installation directory.
*/
private File dir;
@@ -174,6 +175,15 @@
{
throw new BuildException(this.dir + " is not a directory");
}
+
+ // If the beaHome attribute is not set, guess the bea home
+ // directory using the parent directory of this.dir
+ if (this.beaHome == null)
+ {
+ getLog().debug("Extrapolating beaHome to be ["
+ + this.dir.getParentFile() + "]");
+ this.beaHome = this.dir.getParentFile();
+ }
}
/**
@@ -189,8 +199,8 @@
java.setDir(new File(this.tmpDir, "testdomain"));
java.createJvmarg().setValue("-hotspot");
- java.createJvmarg().setValue("-ms64m");
- java.createJvmarg().setValue("-mx64m");
+ java.createJvmarg().setValue("-Xms32m");
+ java.createJvmarg().setValue("-Xmx200m");
File serverDir = new File(this.dir, "server");
@@ -206,9 +216,9 @@
java.addSysproperty(
createSysProperty("bea.home", this.beaHome));
java.addSysproperty(
- createSysProperty("weblogic.management.username", "system"));
+ createSysProperty("weblogic.management.username", "weblogic"));
java.addSysproperty(
- createSysProperty("weblogic.management.password", "password"));
+ createSysProperty("weblogic.management.password", "weblogic"));
java.addSysproperty(
createSysProperty("java.security.policy",
"=./server/lib/weblogic.policy"));
@@ -248,9 +258,9 @@
java.createArg().setValue("-url");
java.createArg().setValue("t3://localhost:" + getPort());
java.createArg().setValue("-username");
- java.createArg().setValue("system");
+ java.createArg().setValue("weblogic");
java.createArg().setValue("-password");
- java.createArg().setValue("password");
+ java.createArg().setValue("weblogic");
java.createArg().setValue("SHUTDOWN");
java.execute();
}
@@ -280,50 +290,13 @@
new File(testDomainDir, "config.xml"),
filterChain);
ResourceUtils.copyResource(getProject(),
- RESOURCE_PATH + "weblogic7x/fileRealm.properties",
- new File(testDomainDir, "fileRealm.properties"),
- filterChain);
- ResourceUtils.copyResource(getProject(),
- RESOURCE_PATH + "weblogic7x/fileRealm.properties",
- new File(testDomainDir, "fileRealm.properties"),
- filterChain);
- ResourceUtils.copyResource(getProject(),
- RESOURCE_PATH + "weblogic7x/SerializedSystemIni.dat",
- new File(testDomainDir, "SerializedSystemIni.dat"),
- filterChain);
- ResourceUtils.copyResource(getProject(),
RESOURCE_PATH + "weblogic7x/DefaultAuthenticatorInit.ldift",
new File(testDomainDir, "DefaultAuthenticatorInit.ldift"),
filterChain);
- File testServerDir = createDirectory(testDomainDir, "testserver");
- File ldapFilesDir =
- createDirectory(testServerDir, "ldap/ldapfiles");
- ResourceUtils.copyResource(getProject(), RESOURCE_PATH
- + "weblogic7x/testserver/ldap/ldapfiles/EmbeddedLDAP.data",
- new File(ldapFilesDir, "EmbeddedLDAP.data"),
- filterChain);
- ResourceUtils.copyResource(getProject(), RESOURCE_PATH
- + "weblogic7x/testserver/ldap/ldapfiles/EmbeddedLDAP.delete",
- new File(ldapFilesDir, "EmbeddedLDAP.delete"),
- filterChain);
- ResourceUtils.copyResource(getProject(), RESOURCE_PATH
- + "weblogic7x/testserver/ldap/ldapfiles/EmbeddedLDAP.index",
- new File(ldapFilesDir, "EmbeddedLDAP.index"),
- filterChain);
- ResourceUtils.copyResource(getProject(), RESOURCE_PATH
- + "weblogic7x/testserver/ldap/ldapfiles/EmbeddedLDAP.tran",
- new File(ldapFilesDir, "EmbeddedLDAP.tran"),
- filterChain);
- ResourceUtils.copyResource(getProject(), RESOURCE_PATH
- + "weblogic7x/testserver/ldap/ldapfiles/EmbeddedLDAP.trpos",
- new File(ldapFilesDir, "EmbeddedLDAP.trpos"),
- filterChain);
- ResourceUtils.copyResource(getProject(), RESOURCE_PATH
- + "weblogic7x/testserver/ldap/ldapfiles/EmbeddedLDAP.twpos",
- new File(ldapFilesDir, "EmbeddedLDAP.trwpos"),
- filterChain);
-
+ // TODO: For improvement, do not copy the weblogic.xml file
+ // in the tmpdir.
+
// Extract the weblogic.xml descriptor
File weblogicXml = new File(this.tmpDir, "weblogic.xml");
ResourceUtils.copyResource(getProject(),
@@ -331,7 +304,7 @@
weblogicXml, filterChain);
// deploy the web-app by copying the WAR file into the applications
// directory, adding the weblogic.xml descriptor
File applicationsDir =
createDirectory(testDomainDir, "applications");
Jar jar = (Jar) createAntTask("jar");
@@ -340,10 +313,11 @@
ZipFileSet zip = new ZipFileSet();
zip.setSrc(getDeployableFile());
jar.addZipfileset(zip);
- FileSet fileSet = new FileSet();
+ ZipFileSet fileSet = new ZipFileSet();
fileSet.setDir(this.tmpDir);
fileSet.createInclude().setName("weblogic.xml");
- jar.addFileset(fileSet);
+ fileSet.setPrefix("WEB-INF");
+ jar.addZipfileset(fileSet);
jar.execute();
}
No revision
@@ -89,7 +89,8 @@
private File beaHome;
/**
- * The WebLogic 7.x installation directory.
+ * The WebLogic 7.x installation directory. For example:
+ * "c:/bea/weblogic700".
*/
private File dir;
@@ -331,7 +304,7 @@
weblogicXml, filterChain);
// deploy the web-app by copying the WAR file into the applications
- // directory, adding the weblogic.xml descriptor
+ // directory, adding the weblogic.xml descriptor in WEB-INF
File applicationsDir =
createDirectory(testDomainDir, "applications");
No revision
1.3.2.1 +5 -5
jakarta-cactus/integration/ant/src/java/org/apache/cactus/integration/ant/deployment/WebXmlVersion.java